@@ -1,19 +1,21 @@
 #' Adjusted Predictions
 #'
-#' This function calculates adjusted predictions for each row of the dataset.
-#' The `datagrid()` function and the `newdata` argument can be used to
-#' calculate Average Adjusted Predictions (AAP), Average Prediction at the Mean
-#' (APM), or Predictions at User-Specified Values of the regressors. See below
-#' for details and examples.
+#' Calculate adjusted predictions for each row of the dataset. The `datagrid()`
+#' function and the `newdata` argument can be used to calculate Average
+#' Adjusted Predictions (AAP), Average Predictions at the Mean (APM), or
+#' Predictions at User-Specified Values of the regressors (aka Adjusted
+#' Predictions at Representative values, APR). See the Details and Examples
+#' sections below.
 #'
-#' An "ajusted prediction" is the outcome predicted by a model for some
-#' combination of the regressors’ values, such as their means or factor levels
-#' (a.k.a. “reference grid”). When possible, this function uses the delta
-#' method to compute the standard error associated with the adjusted
-#' predictions.
+#' An "adjusted prediction" is the outcome predicted by a model for some
+#' combination of the regressors' values, such as their observed values, their
+#' means, or factor levels (a.k.a. “reference grid”). 
+
+#' When possible, this function uses the delta method to compute the standard
+#' error associated with the adjusted predictions.
 #'
-#' A detailed vignette on adjusted predictions and a list of supported models
-#' are published on the package website:
+#' A detailed vignette on adjusted predictions is published on the package
+#' website:
 #'
 #' https://vincentarelbundock.github.io/marginaleffects/
 
@@ -75,14 +77,28 @@ predictions <- function(model,
     # order of the first few paragraphs is important
     # if `newdata` is a call to `typical` or `counterfactual`, insert `model`
     scall <- substitute(newdata)
-    if (is.call(scall) && as.character(scall)[1] %in% c("datagrid", "typical", "counterfactual")) {
+    if (is.call(scall)) {
         lcall <- as.list(scall)
-        if (!any(c("model", "newdata") %in% names(lcall))) {
-            lcall <- c(lcall, list("model" = model))
-            newdata <- eval.parent(as.call(lcall))
+        fun_name <- as.character(scall)[1]
+        if (fun_name %in% c("datagrid", "typical", "counterfactual")) {
+            if (!any(c("model", "newdata") %in% names(lcall))) {
+                lcall <- c(lcall, list("model" = model))
+                newdata <- eval.parent(as.call(lcall))
+            }
+        } else if (fun_name == "visualisation_matrix") {
+            if (!"x" %in% names(lcall)) {
+                lcall <- c(lcall, list("x" = insight::get_data(model)))
+                newdata <- eval.parent(as.call(lcall))
+            }
         }
     }
 
+    # modelbased::visualisation_matrix attaches useful info for plotting
+    attributes_newdata <- attributes(newdata)
+    idx <- c("class", "row.names", "names", "data", "reference")
+    idx <- !names(attributes_newdata) %in% idx
+    attributes_newdata <- attributes_newdata[idx]
+
     # save all character levels for padding
     # later we call call this function again for different purposes
     levels_character <- attr(sanity_variables(model, newdata, variables), "levels_character")
@@ -196,6 +212,11 @@ predictions <- function(model,
     attr(out, "model_type") <- class(model)[1]
     attr(out, "variables") <- variables
 
+    # modelbased::visualisation_matrix attaches useful info for plotting
+    for (a in names(attributes_newdata)) {
+        attr(out, paste0("newdata_", a)) <- attributes_newdata[[a]]
+    }
+
     # bayesian: store draws posterior density draws
     attr(out, "posterior_draws") <- draws
     if (!is.null(draws)) {
