@@ -44,15 +44,18 @@ sanity_model_supported_class <- function(model) {
                       "lmerMod",
                       "lmerModLmerTest",
                       "lmrob",
+                      "lmRob",
                       "lm_robust",
                       "loess",
                       c("lrm", "lm"),
                       c("lrm", "rms", "glm"),
                       c("mblogit", "mclogit"),
+                      c("mclogit", "lm"),
                       c("multinom", "nnet"),
                       c("negbin", "glm", "lm"),
                       c("plm", "panelmodel"),
                       "polr",
+                      "rlmerMod",
                       "rq",
                       c("scam", "glm", "lm"),
                       "speedglm",
