@@ -9,5 +9,5 @@ test_that("padding with interactions", {
     dat <- dat[dat$length < 240,]
     mod <- glm(certified_fresh ~ length * style, data = dat, family = binomial)
     res <- predictions(mod, type = c("response", "link"))
-    expect_predictions(res, n_row = 2)
+    expect_predictions(res, n_row = nrow(dat) * 2)
 })
