@@ -1,5 +1,3 @@
-skip_if_not_installed("crch")
-skip_if_not_installed("ordinal")
 requiet("crch")
 requiet("ordinal")
 
@@ -10,7 +8,7 @@ dat$enssd <- apply(dat[,grep('^rainfc',names(dat))], 1, sd)
 dat$ensmean <- apply(dat[,grep('^rainfc',names(dat))], 1, mean)
 dat <- subset(dat, enssd > 0)
 
-test_that("marginalmeans: crch gaussian: no validity", {
+test_that("marginaleffects: crch gaussian: no validity", {
     model <- crch(sqrt(rain) ~ sqrtensmean + sqrtenssd, data = dat, dist = "gaussian")
     expect_marginaleffects(model, n_unique = 1, type = "location")
 })
@@ -34,7 +32,7 @@ test_that("logistic: no validity", {
 
 test_that("hlxr: no validity", {
     skip("works interactively")
-    q <- unique(quantile(dat$rain, seq(0.1, 0.9, 0.1)))
+    q <- unique(stats::quantile(dat$rain, seq(0.1, 0.9, 0.1)))
     dat$rain_sqrt <- sqrt(dat$rain)
     mod <- hxlr(rain_sqrt ~ sqrtensmean, data = dat, thresholds = sqrt(q))
     expect_marginaleffects(mod, type = "location", n_unique = 1)
@@ -44,8 +42,8 @@ test_that("predictions: crch gaussian: no validity", {
     model <- crch(sqrt(rain) ~ sqrtensmean + sqrtenssd, data = dat, dist = "gaussian")
     pred1 <- predictions(model)
     pred2 <- predictions(model, newdata = head(dat))
-    expect_predictions(pred1, n_row = 1, se = FALSE)
-    expect_predictions(pred2, n_row = 6, se = FALSE)
+    expect_predictions(pred1, n_row = nrow(dat))
+    expect_predictions(pred2, n_row = 6)
 })
 
 
@@ -55,5 +53,5 @@ test_that("marginalmeans: crch gaussian: no validity", {
     model <- crch(sqrt(rain) ~ sqrtensmean + sqrtenssd + categ, 
                   data = tmp, dist = "gaussian")
     mm <- marginalmeans(model)
-    expect_marginalmeans(mm, n_row = 5, se = FALSE)
+    expect_marginalmeans(mm, n_row = 5)
 })
